# imgio

[![Build Status](https://travis-ci.org/toaarnio/imgio.svg?branch=master)](https://travis-ci.org/toaarnio/imgio)

Easy image file reading &amp; writing for Python. Tested on Python 2.7 & 3.5.

Supports PGM / PPM / PNM / PFM / PNG / JPG
